# We are not implementing multiple transformations yet.
# {ARTWORK_ID}-{PURPOSE_CODE}.{TRANSFORMATION_CODE}.{TYPE_CODE}.{EXTENSION}


class FilenameException(Exception):
    """Raised when the filename format is invalid"""

    pass


def validate_artwork_id(artwork_id):
    if artwork_id == "":
        raise ValueError(
            "Missing artwork id. Artwork id should be between 000000 and 099999"
        )
    if len(artwork_id) != 6:
        raise ValueError(
            "Invalid artwork length. Artwork id should have 6 digits. For example: 099999"
        )
    if int(artwork_id) < 0 or int(artwork_id) > 99999:
        raise ValueError(
            "Wrong artwork id. Artwork id should be between 000000 and 099999"
        )


def validate_purpose_code(purpose_code):
    if purpose_code == "":
        raise ValueError("Missing purpose code. Purpose code should be: 32 or 42")
    if int(purpose_code) not in [32, 42]:
        raise ValueError("Wrong purpose code. Purpose code should be: 32 or 42")


def validate_transformacion_code(transformacion_code):
    if transformacion_code == "":
        raise ValueError(
            "Missing transformacion code. Transformacion code should be: 600"
        )
    if int(transformacion_code) not in [600]:
        raise ValueError(
            "Wrong transformacion code. Transformacion code should be: 600"
        )


def validate_type_code(type_code):
    if type_code == "":
        raise ValueError("Missing type code. Type code should be: 2")
    if type_code != "2":
        raise ValueError("Wrong type code. Type code should be: 2")


def validate_extension(extension):
    if extension == "":
        raise ValueError("Missing extention. Extension should be: tif")
    if extension != "tif":
        raise ValueError("Wrong extention. Extension should be: tif")


def validate_filename(filename):
    artwork_id, char, rest = filename.partition("-")
    purpose_code, char, rest = rest.partition(".")
    transformacion_code, char, rest = rest.partition(".")
    type_code, char, rest = rest.partition(".")
    extension, char, rest = rest.partition(".")

    validate_artwork_id(artwork_id)
    validate_purpose_code(purpose_code)
    validate_transformacion_code(transformacion_code)
    validate_type_code(type_code)
    validate_extension(extension)


def validate_filenames(filenames):
    for filename in filenames:
        try:
            validate_filename(filename)
        except ValueError as error:
            raise FilenameException(f"Invalid filename {filename}. {error}")



import nautilus_librarian.mods.dvc.typer.commands
import nautilus_librarian.mods.git.typer.commands
import nautilus_librarian.mods.gpg.typer.commands
import nautilus_librarian.mods.libvips.typer.commands
import nautilus_librarian.mods.namecodes.typer.commands
import nautilus_librarian.typer.commands


def add_commands(app):
    app.command()(nautilus_librarian.typer.commands.test)


def add_subcommands(app):
    app.add_typer(nautilus_librarian.mods.dvc.typer.commands.app, name="dvc")
    app.add_typer(nautilus_librarian.mods.git.typer.commands.app, name="git")
    app.add_typer(nautilus_librarian.mods.gpg.typer.commands.app, name="gpg")
    app.add_typer(nautilus_librarian.mods.libvips.typer.commands.app, name="libvips")
    app.add_typer(
        nautilus_librarian.mods.namecodes.typer.commands.app, name="namecodes"
    )


def app_init(app):
    add_commands(app)
    add_subcommands(app)



import os

from nautilus_librarian.mods.namecodes.domain.file_locator import file_locator
from nautilus_librarian.mods.namecodes.domain.filename import Filename


class InvalidImageFolderException(Exception):
    """Raised when the file is located in a wrong path"""

    pass


def validate_filepath(filepath):
    # Gold Image: data/000001/32/000001-32.600.2.tif
    # Base Image: data/000001/42/000001-32.600.2.tif

    actual_folder = os.path.dirname(filepath)

    filename = Filename(os.path.basename(filepath))

    expected_folder = file_locator(filename)

    if expected_folder != actual_folder:
        raise InvalidImageFolderException(
            f'Invalid folder for image. The file "{ filepath }" should be in the folder "{ expected_folder }"'
        )


def validate_filepaths(filepaths):
    for filepath in filepaths:
        validate_filepath(filepath)



import typer

app = typer.Typer()


@app.command()
def test(echo_string: str):
    """
    It's only used for testing purposes
    """
    typer.echo(f"Testing GPG module: {echo_string}")


if __name__ == "__main__":
    app()



from enum import Enum

import typer

app = typer.Typer()


@app.command()
def test(echo_string: str):
    """
    It's only used for testing purposes
    """
    typer.echo(f"Testing LibVips module: {echo_string}")


class Step(Enum):
    validate_size = "validate_size"
    resize = "resize"
    modify_icc_profile = "modify_icc_profile"


def validate_size():
    print("- Validating size of the images")


def resize():
    print("- Resizing images")


def icc_modify():
    print("- Modifying ICC color profiles")


def execute_pipeline():
    validate_size()
    resize()
    icc_modify()


stepExecuters = {
    "validate_size": validate_size,
    "resize": resize,
    "modify_icc_profile": icc_modify,
}


@app.command()
def process(step: Step = None):
    """
    Execute the image processing pipeline.

    If --step is used, only specified step is executed.
    """
    if not step:
        execute_pipeline()
    else:
        typer.echo(f"Processing images, using step {step}")
        stepExecuters[step.value]()


if __name__ == "__main__":
    app()



import os

from filename import Filename


class FilepathException(Exception):
    """Raised when the file is located in a wrong path"""

    pass


def validate_filepath(filepath):
    # data/000001/32/000001-32.600.2.tif

    basename = os.path.basename(filepath)

    filename = Filename(basename)

    print(filename)


def parse_filename(filename):
    artwork_id, char, rest = filename.partition("-")
    purpose_code, char, rest = rest.partition(".")
    transformacion_code, char, rest = rest.partition(".")
    type_code, char, rest = rest.partition(".")
    extension, char, rest = rest.partition(".")



import typer

from nautilus_librarian.mods.namecodes.domain.validate_filenames import (
    validate_filename,
)

app = typer.Typer()


@app.command()
def test(echo_string: str):
    """
    It's only used for testing purposes
    """
    typer.echo(f"Testing Namecode module: {echo_string}")


@app.command("validate-filename")
def validate_filename_command(filename: str):
    """
    Validate filename with Nautilus Namecodes Specification.

    More information about the specification on: https://github.com/da2ce7/nautilus-namecodes.

    Filename examples: 000000-32.600.2.tif, 000001-42.600.2.tif.

    EXAMPLES:

        nautilus-librarian namecodes validate-filename 000000-32.600.2.tif

        A valid filename will show nothing.

        nautilus-librarian namecodes validate-filename 00000032.600.2.tif

        An invalid filename will throw an exception.
    """
    validate_filename(filename)


if __name__ == "__main__":
    app()



class Filename:
    def __init__(self, filename):
        self.parse(filename)

    def parse(self, filename):
        self.filename = filename
        self.artwork_id, char, rest = filename.partition("-")
        self.purpose_code, char, rest = rest.partition(".")
        self.transformacion_code, char, rest = rest.partition(".")
        self.type_code, char, rest = rest.partition(".")
        self.extension, char, rest = rest.partition(".")

    def __str__(self):
        return self.filename



"""Main Module for Command Line App"""

import typer
from typer.main import Typer

from nautilus_librarian.typer.app import app_init

app: Typer = typer.Typer()

app_init(app)

if __name__ == "__main__":
    app()



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['nautilus_librarian',
 'nautilus_librarian.mods',
 'nautilus_librarian.mods.dvc',
 'nautilus_librarian.mods.dvc.domain',
 'nautilus_librarian.mods.dvc.typer',
 'nautilus_librarian.mods.git',
 'nautilus_librarian.mods.git.domain',
 'nautilus_librarian.mods.git.typer',
 'nautilus_librarian.mods.gpg',
 'nautilus_librarian.mods.gpg.domain',
 'nautilus_librarian.mods.gpg.typer',
 'nautilus_librarian.mods.libvips',
 'nautilus_librarian.mods.libvips.domain',
 'nautilus_librarian.mods.libvips.typer',
 'nautilus_librarian.mods.namecodes',
 'nautilus_librarian.mods.namecodes.domain',
 'nautilus_librarian.mods.namecodes.typer',
 'nautilus_librarian.typer']

package_data = \
{'': ['*']}

install_requires = \
['GitPython>=3.1.24',
 'PyGithub>=1.55',
 'dvc[azure]>=2.8.3,<3.0.0',
 'mypy>=0.910,<0.911',
 'pyvips>=2.1.16',
 'typer[all]>=0.4.0,<0.5.0']

entry_points = \
{'console_scripts': ['nautilus-librarian = nautilus_librarian.main:app']}

setup_kwargs = {
    'name': 'nautilus-librarian',
    'version': '0.1.0',
    'description': 'A Python Console application to handle media libraries like Git and DVC',
    'long_description': '# Nautilus Librarian\n\n[![Lint Code Base](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/linter.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/linter.yml)[![Publish Docker image](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/publish-docker-image.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/publish-docker-image.yml)[![Test](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/test.yml/badge.svg)](https://github.com/Nautilus-Cyberneering/librarian/actions/workflows/test.yml)\n\nA Python Console application to handle media libraries like Git and [Dvc](https://github.com/iterative/dvc).\n\n## Development\n\n### Run\n\nWith docker:\n\nBuild:\n\n```shell\n./bin/docker/build.sh\n```\n\nRun pre-built docker image:\n\n```shell\n./bin/docker/run.sh [OPTIONS] COMMAND [ARGS]...\n./bin/docker/run.sh --help\n```\n\nRun mounting current repo:\n\n```shell\n./bin/docker/run-dev.sh [OPTIONS] COMMAND [ARGS]...\n./bin/docker/run-dev.sh --help\n```\n\nWith Poetry:\n\n```shell\npoetry install\npoetry run nautilus-librarian [OPTIONS] COMMAND [ARGS]...\npoetry run nautilus-librarian --help\n```\n\n> NOTE: With Poetry, you have to install the [Librarian system dependencies](https://github.com/Nautilus-Cyberneering/librarian-system-dockerfile).\n\n### Testing\n\nWith docker:\n\n```shell\n./bin/docker/test.sh\n```\n\nWith Poetry:\n\n```shell\npoetry shell\npytest\n```\n\nor:\n\n```shell\npoetry run pytest --cov\n```\n\n### Linting\n\nFor Dockerfile:\n\nWe are using GitHub Action [super-linter](https://github.com/marketplace/actions/super-linter). If you want to check the `Dockerfile` linting before pushing, you can do it with:\n\n```shell\ndocker run --rm -i hadolint/hadolint < Dockerfile\n```\n\nRun super-linter locally with [act](https://github.com/nektos/act):\n\n```shell\nact -W .github/workflows/linter.yml -j build\n```\n',
    'author': 'Jose Celano',
    'author_email': 'jose@nautilus-cyberneering.de',
    'maintainer': 'Jose Celano',
    'maintainer_email': 'jose@nautilus-cyberneering.de',
    'url': 'https://github.com/Nautilus-Cyberneering/librarian',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
